@@ -1,6 +1,5 @@
 from django import forms
 from django.contrib import admin, auth
-from django.contrib.admin.sites import NotRegistered
 from django.contrib.admin.views.main import ChangeList
 from django.db import connection
 from django.db.models import Count, F, Q
@@ -26,7 +25,7 @@ from ..models import Program, Form, FormLabel, FormBlock, FormDependency, \
 from ..filetype import FileType
 from ..plugins import get_matching_plugin
 from ..signals import register_program_settings, register_form_settings, \
-    register_user_actions
+    register_user_actions, form_published_changed
 from ..utils import submission_link
 from .actions import move_blocks_action, send_email_action, UserActionsMixin, \
     FormActionsMixin, SubmissionActionsMixin
@@ -37,16 +36,9 @@ class FormativeAdminSite(admin.AdminSite):
         self.submissions_registered = None
         super().__init__(*args, **kwargs)
     
-    def unregister_by_table(self, model):
-        match = None
-        for m in self._registry.keys():
-            if m._meta.db_table == model._meta.db_table: match = m
-        
-        if match: self.unregister(match)
-    
     def register_submission_models(self):
         for model in self.submissions_registered or {}:
-            self.unregister_by_table(model)
+            self.unregister(model)
         self.submissions_registered = {}
         
         if Form._meta.db_table in connection.introspection.table_names():
@@ -57,6 +49,8 @@ class FormativeAdminSite(admin.AdminSite):
                 if form.item_model:
                     self.register(form.item_model, SubmissionItemAdmin)
                     self.submissions_registered[form.item_model] = True
+        
+        form_published_changed.send(self)
 
 
 site = FormativeAdminSite()
@@ -67,7 +61,7 @@ site.register(auth.models.Group, auth.admin.GroupAdmin)
 @admin.register(auth.models.User, site=site)
 class UserAdmin(UserActionsMixin, auth.admin.UserAdmin):
     change_list_template = 'admin/formative/user/change_list.html'
-    actions = ['send_password_reset']
+    actions = ['make_active', 'make_inactive', 'send_password_reset']
     
     def get_actions(self, request):
         actions = super().get_actions(request)
@@ -78,6 +72,16 @@ class UserAdmin(UserActionsMixin, auth.admin.UserAdmin):
             func.__name__ = name
             actions[name] = self.get_action(func)
         return actions
+    
+    def make_active_ornot(self, request, qs, active=True):
+        for obj in qs:
+            obj.is_active = active
+            obj.save()
+        self.message_user(request, 'User status changed.')
+    def make_active(self, request, queryset):
+        return self.make_active_ornot(request, queryset)
+    def make_inactive(self, request, queryset):
+        return self.make_active_ornot(request, queryset, active=False)
 
 
 @admin.register(Program, site=site)
